from Python_Peatio.Auth import Auth
from Python_Peatio.Market import Market
from Python_Peatio.Accounts import Accounts
from Python_Peatio.UserAPI_Markets import UserAPI_Markets
from Python_Peatio.UserAPI_Public import UserAPI_Public


import hmac
import hashlib 
import binascii
import time


class Auth:
    def __init__(self, access_key, secret_key):
        self.access_key = access_key
        self.secret_key = secret_key

    def signed_param(self):
        nonce = int(time.time() * 1000)
        byte_key = bytes(self.secret_key, 'UTF-8')
        message = (str(nonce) + self.access_key).encode()
        signature = hmac.new(byte_key, message, hashlib.sha256).hexdigest()
        headers = {
        'X-Auth-Apikey': self.access_key,
        'X-Auth-Nonce': nonce,
        'X-Auth-Signature': signature
        }
        return nonce, signature

    def header(self):
        nonce = int(time.time() * 1000)
        byte_key = bytes(self.secret_key, 'UTF-8')
        message = (str(nonce) + self.access_key).encode()
        signature = hmac.new(byte_key, message, hashlib.sha256).hexdigest()
        header = {
        'X-Auth-Apikey': self.access_key,
        'X-Auth-Nonce': nonce,
        'X-Auth-Signature': signature
        }
        return header


import hmac
import hashlib 
import binascii
import time
import json
import http.client
from Python_Peatio.Auth import Auth

class UserAPI_Public(Auth):

    def trading_fees(self, URL : str)  -> list:
        "Returns trading_fees table as paginated collection"
        conn = http.client.HTTPConnection(URL)
        conn.request("GET", "/api/v2/peatio/public/trading_fees")
        trading_fees = json.loads(conn.getresponse().read().decode("utf-8"))


        return trading_fees


import hmac
import hashlib 
import binascii
import time
import json
import http.client
from Python_Peatio.Auth import Auth

class Accounts(Auth):

    def account_balances_currency(self, URL : str, currency : str)  -> dict:
        "Get list of user accounts balances of selected currency"
        payload = {}
        header = Auth.header(self)
        conn = http.client.HTTPConnection(URL)
        conn.request("GET", "/api/v2/peatio/account/balances/{currency}".format(currency = currency), payload, header)
        currency_balance = json.loads(conn.getresponse().read().decode("utf-8"))

        return currency_balance


    def all_currency_balance(self, URL : str)  -> list:
        "Get list of user accounts balances of all currency"
        payload = {}
        header = Auth.header(self)
        conn = http.client.HTTPConnection(URL)
        conn.request("GET", "/api/v2/peatio/account/balances", payload, header)
        all_currency_balance = json.loads(conn.getresponse().read().decode("utf-8"))

        return all_currency_balance


from setuptools import setup, find_packages
import codecs
import os

VERSION = '1.4.0'
DESCRIPTION = 'Python Package for Openware Peatio Cryptocurrency Exchange & Accounting Software'
LONG_DESCRIPTION = 'A Python package that allows you to do API based operation on Peatio Cryptocurrency Exchange. This Package is based on following [API](https://www.openware.com/sdk/2.3/docs/peatio/api/peatio-user-api-v2.html) documentation. Peatio is core open-source accounting software for a cryptocurrency and digital asset exchange platform. The mission of Peatio is to facilitate asset base, accounting, and trading activities. It is built on Rails framework and designed for micro-services architecture, with external frontend and server components.'

with open("README.md", "r") as fh:
    long_description = fh.read()
# Setting up
setup(
    name="Python_Peatio",
    version=VERSION,
    author="Kumar Saurav",
    author_email="<kumar@prescient-automation.com>",
    website = "https://prescient-automation.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=['python-http-client'],
    keywords=['python', 'peatio', 'crypto', 'crypto currency', 'open source', 'exchanges', 'open source exchange', 'openware exchange'],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)


import hmac
import hashlib 
import binascii
import time
import json
import http.client
from Python_Peatio.Auth import Auth

class Market(Auth):

    def trades(self, URL : str, limit = 1, page = 1, order_by = 'desc')  -> dict:
        "Get your executed trades. Trades are sorted in reverse creation order."
        conn = http.client.HTTPConnection(URL)
        conn.request("GET", "/api/v2/peatio/public/markets/tickers?limit={limit}&page={page}&order_by={order_by}".format(limit= limit, page = page, order_by= order_by))
        trades = json.loads(conn.getresponse().read().decode("utf-8"))

        return trades
    
    

    def all_cancel_custom(self, URL : str, side, market)  -> dict:
        "Cancel all my orders custom. If only asks order to cancel pass asks, if only asks order of btc usdt need to be cancelled then pass btcusdt"
        cancel_payload = "{\r\n \"side\" : \"%s\", \r\n \"market\" : \"%s\"\r\n}"% (side, market)
        header = Auth.header(self)
        conn = http.client.HTTPConnection(URL)
        conn.request("POST", "/api/v2/peatio/market/orders/cancel", cancel_payload, header)
        all_cancel_custom = json.loads(conn.getresponse().read().decode("utf-8"))

        return all_cancel_custom

    def all_cancel(self, URL : str)  -> dict:
        "Cancel all my orders. Bids & Asks all cancelled of all market"
        cancel_payload = "{}"
        header = Auth.header(self)
        conn = http.client.HTTPConnection(URL)
        conn.request("POST", "/api/v2/peatio/market/orders/cancel", cancel_payload, header)
        all_cancel = json.loads(conn.getresponse().read().decode("utf-8"))

        return all_cancel

    def id_cancel(self, URL : str, id : int)  -> dict:
        "Cancel an order by order id."
        cancel_payload = "{}"
        header = Auth.header(self)
        conn = http.client.HTTPConnection(URL)
        conn.request("POST", "/api/v2/peatio/market/orders/{id}/cancel".format(id = id), cancel_payload, header)
        id_cancel = json.loads(conn.getresponse().read().decode("utf-8"))

        return id_cancel

    def create_limit_order(self, URL : str, market : str, side : str, volume : str, price : str )  -> dict:
        "Create a Sell/Buy order."
        payload = "{\r\n    \"market\": \"%s\",\r\n    \"side\" : \"%s\", \r\n    \"volume\" : \"%s\", \r\n    \"ord_type\" : \"limit\",\r\n    \"price\" : \"%s\"\r\n}"% (market, side, volume, price)
        header = Auth.header(self)
        conn = http.client.HTTPConnection(URL)
        conn.request("POST", "/api/v2/peatio/market/orders", payload, header)
        new_limit_order = json.loads(conn.getresponse().read().decode("utf-8"))

        return new_limit_order


    def get_order(self, URL : str, limit = 100, page = 1, order_by = 'desc', ord_type = 'limit')  -> dict:
        "Get your orders, result is paginated."
        payload = {}
        header = Auth.header(self)
        conn = http.client.HTTPConnection(URL)
        conn.request("GET", "/api/v2/peatio/market/orders?limit={}&page={}&ordering={}&ord_type={}".format(limit, page, order_by, ord_type), payload, header)
        orders = json.loads(conn.getresponse().read().decode("utf-8"))

        return orders


import hmac
import hashlib 
import binascii
import time
import http.client
import json
from Python_Peatio.Auth import Auth

class UserAPI_Markets(Auth):

    def all_markets_tickers(self, URL : str)  -> dict:
        "Get ticker of all markets"
        conn = http.client.HTTPConnection(URL)
        conn.request("GET", "/api/v2/peatio/public/markets/tickers")
        all_tickers = json.loads(conn.getresponse().read().decode("utf-8"))

        return all_tickers

    def market_tickers(self, market : str, URL : str)  -> dict:
        "Get ticker of specific market."
        conn = http.client.HTTPConnection(URL)
        conn.request("GET", "/api/v2/peatio/public/markets/{}/tickers".format(market))
        market_tickers = json.loads(conn.getresponse().read().decode("utf-8"))

        return market_tickers
    
    def markets_tickers_klines(self, market : str, URL : str , period = 1, limit = 30) -> dict:
        "Get OHLC(k line) of specific market."
        conn = http.client.HTTPConnection(URL)
        conn.request("GET", "/api/v2/peatio/public/markets/{}/k-line?period={}&limit={}".format(market, period, limit))
        klines = json.loads(conn.getresponse().read().decode("utf-8"))

        return klines
    
    def markets_tickers_depth(self, market : str, URL : str, limit = 300) -> dict:
        "Get depth or specified market. Both asks and bids are sorted from highest price to lowest."
        conn = http.client.HTTPConnection(URL)
        conn.request("GET", "/api/v2/peatio/public/markets/{}/depth?limit={}".format(market, limit))
        depth = json.loads(conn.getresponse().read().decode("utf-8"))

        return depth

    def markets_tickers_trades(self, market : str, URL : str, limit = 100, order_by = 'desc') -> dict:
        "Get recent trades on market, each trade is included only once. Trades are sorted in reverse creation order."
        conn = http.client.HTTPConnection(URL)
        conn.request("GET", "/api/v2/peatio/public/markets/{}/trades?limit={}&order_by={}".format(market, limit, order_by))
        trades = json.loads(conn.getresponse().read().decode("utf-8"))

        return trades

    def markets_tickers_order_book(self, market : str, URL : str, asks_limit = 10, bids_limit =10) -> dict:
        "Get the order book of specified market."
        conn = http.client.HTTPConnection(URL)
        conn.request("GET", "/api/v2/peatio/public/markets/{}/order-book?asks_limit={}&bids_limit={}".format(market, asks_limit, bids_limit))
        order_book = json.loads(conn.getresponse().read().decode("utf-8"))

        return order_book

    def all_markets(self, URL : str, limit = 100, page = 1, ordering = 'asc') -> dict:
        "Get all available markets."
        conn = http.client.HTTPConnection(URL)
        conn.request("GET", "/api/v2/peatio/public/markets?limit={}&page={}&ordering={}".format(limit, page, ordering))
        all_markets = json.loads(conn.getresponse().read().decode("utf-8"))

        return all_markets

